/*
 * ==========================================
 * OpenCA Iface 2.0 - Dynamic Javascript Menu
 * (c) by Massimiliano Pala and OpenCA Team
 * All Rights Reserved
 * ==========================================
 * OpenCA Licensed Software
 * ==========================================
 */

var xmlDoc = null;
var request = null;

function genXMLMenu ( fname, objID, addLink ) {

	if( window.XMLHttpRequest ) {
		if( typeof(XMLHttpRequest) != 'undefined' ) {
			try {
				request = new XMLHttpRequest();
			} catch ( e ) {
				request = false;
			}
		}
	} else if ( window.ActiveXObject ) {
		try {
			request = new ActiveXObject( 'Msxml2.XMLHTTP' );
		} catch ( e ) {
			try {
				request = new ActiveXObject('Microsoft.XMLHTTP');
			} catch ( e ) {
				request = false;
			}
		}
	}

	if( request == false ) {
		alert ("Browser is not supported!");
		return;
	}

	request.open('GET', fname, true );
	request.onreadystatechange = function () { parseXMLConfig (objID, addLink) };
	request.send(null);

	return;
}

function parseXMLConfig ( objID, addLink ) {

	/* xmlDoc, request are general variables */
	var response = null;

	if ( request.readyState == 4 ) {
		if( request.status == 200 ) {
			response = request.responseText;
		} else {
			try {
				response = request.responseText;
			} catch ( e ) {
				alert ( "ERROR, can not find menu configuration");
				request = null;
			}
		};
	} else {
		return ( null );
	}

	if ( window.ActiveXObject ) {
		xmlDoc = new ActiveXObject('Microsoft.XMLDOM');
		xmlDoc.async = false;
		xmlDoc.loadXML ( response );
	} else if ((document.implementation) &&
			(document.implementation.createDocument) ) {
		try {
			xmlDoc = document.implementation.createDocument('','', null );
			xmlDoc.loadXML( response );
		} catch ( e ) {
			try {
				parser = new DOMParser();
				xmlDoc = parser.parseFromString( response, "text/xml" );
			} catch ( e ) {
				alert ( "Browser is not suppoted (line 96)");
				return null;
			}
		}
	} else {
		alert ( "Browser not supported (line 100)" );
		return null;
	}


	if( xmlDoc ) {
		createMenu( objID, xmlDoc, addLink );
	}

	return xmlDoc;

}

/* 
 * Show/Hide/Click functions for menu displaying 
 */

function showMenu( el, type ) {
	var list;
	var type;

	list = el.childNodes;
	if( type == null ) {
		type = 'TABLE';
	}

	for ( i=0; i < list.length; i++ ) {

		if(( list[i].nodeName == 'DIV' ) &&
			( list[i].className == "submenuitem" ) ) {
			list[i].style.borderStyle = 'solid';
			list[i].style.borderColor = '#ccc';
			list[i].style.borderWidth = '1px';
		}

		if( list[i].nodeName != type ) {
			continue;
		};
		list[i].style.display = '';
	}
}

function clickMenu( el ) {
	var list;

	list = el.childNodes;

	for ( var i=0; i < list.length; i++ ) {
		if( list[i].nodeName != "TABLE" ) {
			continue;
		};
		if( list[i].style.display == 'none' ) {
			list[i].style.display = 'block';
		} else {
			list[i].style.display = 'none';
		}
	}
}

function hideMenu( el ) {
	var list;

	list = el.childNodes;
	for ( i=0; i < list.length; i++ ) {

		if(( list[i].nodeName == 'DIV' ) &&
				( list[i].className == "submenuitem" ) ) {
			list[i].style.borderStyle = 'none';
		}

		if( list[i].nodeName != "TABLE" ) {
			continue;
		};
		list[i].style.display = 'none';
	};
}

function setClass ( obj, cls ) { 

	if( (obj == null) || (cls == null) ) {
		return false;
	}

	try {
		obj.setAttribute ( "class", cls );
		obj.setAttribute ( "className", cls );
	} catch ( e ) {
		alert ("ERROR: Menu generation");
	}
}

function createTableObj ( obj, cls, disp ) {
	var table;
	var tbody;
	var tr;
	var td;

	if ( obj == null ) {
		return false;
	}

	table = document.createElement ( "table" );
	tbody = document.createElement ( "tbody" );

	table.appendChild( tbody );
	obj.appendChild ( table );

	if( cls ) {
		setClass( table, cls );
	}

	if ( disp == false ) {
		table.style.display = 'none';
	}

	return table;
}

function createSubMenu ( obj, menuNodes, cls, addLink ) {

	var table;
	var tbody;
	var cldName;

	if( (obj == null) || ( menuNodes == null ) ) {
		return false;
	} 

	if( cls < 1 ) {
		clsName = "submenu";
	} else {
		clsName = "subsubmenu";
	}

	table = document.createElement ( "table" );
	tbody = document.createElement ( "tbody" );

	table.appendChild( tbody );
	obj.appendChild ( table );

	if( clsName ) {
		setClass( table, clsName );
	}

	table.style.display = 'none';

	for ( var i = 0; i < menuNodes.length; i++) {
		var tr;
		var td;
		var div;
		var lst;
		var enabled = 1;

		var node;
		var name;
		var lnk;
		var img;

		node = menuNodes[i];
		enabled = 1;

		if ( (node.nodeName != "item") && 
				(node.nodeName != "submenu") ) {
			continue;
		}

		tr = document.createElement( "tr" );
		td = document.createElement( "td" );

		name = node.getAttribute("name");
		lnk = node.getAttribute("lnk");
		img = node.getAttribute("img");

		if ( ( lnk == "") && ( node.childNodes.length == 0 ) ) {
			td.style.color = "#bbb";
			enabled = 0;
		}

		if( node.childNodes.length > 0 ) {
			createSubMenu ( td, node.childNodes, cls + 1, addLink );
		}

		div = document.createElement( "div" );

		if( name ) {
			if( lnk ) {
				var target = "";
				var lnkObj = document.createElement('a');

				target = lnk + addLink;
				lnkObj.setAttribute('href', target);
				lnkObj.innerHTML = name;
				div.appendChild( lnkObj );
			} else {
				div.innerHTML = name;
			}
		} else {
			hr = document.createElement("hr");
			div.appendChild( hr );
			enabled = 0;
		}

		if( enabled == 1 ) {
			setClass( div, "submenuitem" );
		} else {
			if ( name ) {
				setClass( div, "submenuitemoff" );
			} else {
				setClass ( div, "submenuseparator" );
			}
		}

		td.appendChild( div );

		if( enabled == 1 ) {
			try {
				td.onmouseover = function() {showMenu(this,null)};
				td.onmouseout = function() {hideMenu(this)};
				td.onclick = function() {clickMenu(this)};
			} catch ( e ) {
				td.setAttribute ("onMouseover", "showMenu(this,null);");
				td.setAttribute ("onMouseout", "hideMenu(this);" );
				td.setAttribute ("onClick", "clickMenu(this);" );
			}
		}

		tr.appendChild( td );

		tbody.appendChild( tr );
	}

	return tbody;
}

function createMenu ( objId, xmlDoc, addLink ) {
	var table;
	var tbody;
	var row;
	var config;
	var currlist;
	var menuObject;
	var width;
	var menuNum = 0;

	var obj = document.getElementById( objId );

	if( obj == null ) {
		alert ( "ERROR: menu not found!" );
	}

	var menulist = xmlDoc.childNodes;
	var mainNode = xmlDoc.getElementsByTagName("openca");

	if ( ! mainNode ) {
		alert ( "Menu Generation Error (missing openca node in config)!");
		return;
	}

	currlist = mainNode[0].childNodes;

	menuObject = document.createElement ( "table" );
	tbody = document.createElement ( "tbody" );

	menuObject.appendChild( tbody );
	setClass ( menuObject, "nav" );

	obj.appendChild ( menuObject );

	row = document.createElement( "tr" );
	tbody.appendChild( row );

	menuNum = 0;
	for ( var i = 0 ; i < currlist.length;i++ ) {
		if ( currlist[i].nodeName == "menu" ) {
			menuNum++;
		}
	}

	if( menuNum == 0 ) {
		menuNum++;
	}

	width = 100 / menuNum;

	for( var i = 0 ; i < currlist.length; i++ ) {
		var tab;
		var td;
		var node;
		var name;

		node = currlist[i];
		if( node.nodeName != "menu" ) {
			continue;
		};

		name = node.getAttribute("name");
		if ( name == "" ) {
			continue;
		}

		td = document.createElement( "td" );
		div = document.createElement( "div" );
		setClass( div, "menuitem" );

		td.setAttribute("width", width + "%");

		if( name ) {
			/* name.replace(/ /g, "&nbsp;"); */
			div.innerHTML = name;
		} else {
			div.innerHTML = '<center><hr />';
		}

		td.appendChild( div );
		row.appendChild( td );

		try {
			td.onmouseover = function() {showMenu(this,null)};
			td.onmouseout = function() {hideMenu(this)};
			td.onclick = function() {clickMenu(this)};
		} catch ( e ) {
			td.setAttribute ("onMouseover", "showMenu(this,null);");
			td.setAttribute ("onMouseout", "hideMenu(this);" );
			td.setAttribute ("onClick", "clickMenu(this);" );
		}

		if( node.childNodes.length > 0 ) {
			createSubMenu ( td, node.childNodes, 0, addLink );
		}
	}
}
